@@ -1,5 +1,7 @@
 test_that("ping", {
   expect_type(ping_ollama(), "logical")
+  expect_type(ping_ollama(silent = TRUE), "logical")
+  expect_no_message(ping_ollama(silent = TRUE))
 })
 
 test_that("verbose", {
